---
author: Wu Sun (<wu.sun@ucla.edu>)

title: Metadata Information for the Hyytiälä Soil Flux Data

date: 13 Feb 2017

---

# General description

- Name of the dataset: Hyytiälä Soil Flux Data (Version 2017.02.13)
- Investigators: 
    * UCLA: Wu Sun, Ulli Seibt
    * The Open University (UK): Kadmiel Maseyk
    * University of Groningen: Linda M. J. Kooijmans, Huilin Chen
    * University of Helsinki: Ivan Mammarella, Timo Vesala, Janne Levula, Helmi Keskinen
- Publication: TBD
- Site location: Hyytiälä Forestry Field Station, Finland (61.845° N, 24.288° W, altitude 181 m). More information available at http://www.helsinki.fi/hyytiala/english/
- Period of the record: 29 June 2015 to 2 November 2015
- Funding sources: European Commission’s Seventh Framework Programme (FP7/2007–2013) in the InGOS project under grant contract no. 284274

# Terms of use

This dataset is made available under the Creative Commons CC0 1.0 Universal (CC0 1.0) Public Domain Dedication license: https://creativecommons.org/publicdomain/zero/1.0/, per policy of DataONE Dash (https://oneshare.cdlib.org/), an online self-service tool of UC3 Merritt data repository. For a plain language summary of the CC0 1.0 license, please see https://creativecommons.org/publicdomain/zero/1.0/. Please cite the original publication when using this dataset. 

# Data file description

All data files are in CSV format with ASCII encoding and are readable through Excel or mainstream scientific programming languages like Python and R. Description of data files and variables are as follows.

## Chamber flux data (filtered, and gapfilled for soil variables)

File name: `hyy15_chflux_release.csv`

Variable names:

- `timestamp`: Date and time in UTC following the ISO 8601 standard, `yyyy-mm-dd HH:MM:SS`.
- `doy_utc`, `doy_local`: These are the day of year (DOY) values in UTC and Finish Standard Time (UTC+2), respectively. Please be aware that the DOY values here are *floating numbers*, which are days since 1 Jan 2015 00:00 and are always smaller than the corresponding integer DOY values. For example, the fractional DOY value at noon on June 29, 2015 is 179.5, but the integer DOY value of that day is 180. See http://www.esrl.noaa.gov/gmd/grad/neubrew/Calendar.jsp for the integer DOY table. Note that local daylight saving time (DST) is not used to avoid the missing or overlapping hour associated with DST clock change. 
- `ch_no`: Chamber number, #1 or #2.
- `cos_chb`, `co_chb`, `co2_chb`, `h2o_chb`: "_chb" stands for "chamber open, before". These are the average ambient concentrations before the chamber closure period. Names of gas species are self-evident. Units are: pmol mol^-1^, nmol mol^-1^, µmol mol^-1^, and mmol mol^-1^, respectively.
- `cos_cha`, `co_cha`, `co2_cha`, `h2o_cha`: "_cha" stands for "chamber open, after". These are the average ambient concentrations after the chamber closure period. Same units as the previous ones. 
- `f_cos`, `f_co`, `f_co2`, `f_h2o`: Fluxes of gas species. Units are: pmol m^-2^ s^-1^, nmol m^-2^ s^-1^, µmol m^-2^ s^-1^, and mmol m^-2^ s^-1^, respectively.
- `se_fcos`, `se_fco`, `se_fco2`, `se_fh2o`: Standard errors of fluxes from fitting with same units as the fluxes. 
- `p_ch`: Surface pressure in hPa.
- `flow_lpm`: Flow rate into the chamber, in liter per minute under ambient conditions (not STP condition).
- `T_ch`: Temperature of the chamber air used to calculate the fluxes, approximated by the air temperature at 4.2 m from the SMEAR II data. 
- `T_soil_surf`, `T_soil_A`: Soil humus layer and A horizon temperature (C). Derived from the SMEAR II data.
- `w_soil_surf`, `w_soil_A`: Soil humus layer and A horizon moisture (m^3^ m^-3^). Derived from the SMEAR II data and gapfilled with data from a nearby soil profiling station. 
- `precip`: Precipitation (mm) in half hour interval, from the SMEAR II data. 

## Blank chamber test data

File name: `hyy15_blank.csv`

Variables are the same as those in the filtered chamber flux data file, except that the fluxes are for the blank chamber only (no soil).

## Moss incubation flux data

Filename: `hyy15_moss.csv`

Variables are the same as those in the filtered chamber flux data file, except that the fluxes are for the moss layer only (no soil).

# Contact

For questions regarding this dataset, please contact Wu Sun (wu.sun@ucla.edu) or Ulli Seibt (useibt@ucla.edu).
